@@ -11,14 +11,13 @@
 
 package NEXT::init;
 
-our $VERSION = '0.99.2';
+our $VERSION = '0.99';
 
 use strict;
 use warnings;
 use Carp;
 
 use Symbol;
-use Scalar::Util qw( reftype );
 
 # debug output
 
@@ -49,13 +48,9 @@ use Data::Dumper;
 our $verbose = 0;
 our $debug   = 0;
 
-my %defaultz =
-qw(
-	export	1
-	type	0
-	debug	0
-	verbose	0
-);
+my %defaultz = map { $_ => 0 } qw( export type debug verbose );
+
+$defaultz{export} = 1;
 
 ########################################################################
 # utility subs to handle data on @_.
@@ -126,49 +121,28 @@ sub
 
 	my $class = ref $item || $item;
 
-	my $basetype =  
+	my $basetype = 
 	do
 	{
+		# metadata isn't blessed: its ref will be the
+		# correct type for comparison.
+
 		if( my $sub = $class->can('meta') )
 		{
-			# if this is derived from another N::i-based
-            # class then whatever its metadata type is 
-            # will be re-used here. $meta is extraneous
-            # but reftype $sub->() seems likely to leave
-            # anyone else crosseyed...
-
 			my $meta = $sub->();
 
-			reftype $meta;
+			ref $meta;
 		}
-		elsif( my $type = reftype $_[0] )
+		else
 		{
-            # if the caller passed in referent for the 
-            # first argument use its type if there isn't
-            # a base class to get it from.
-
-            $type
+			''
 		}
-        else
-        {
-            # passed a simple list: use whatever the list
-            # defines for itself via the :type (i.e., no 
-            # further sanity check on the basename).
-
-            ''
-        }
 	};
 
-    # now figure out the appropriate type for this new
-    # class: either it has passed a ref in $_[0], which
-    # means to use that type as the current metadata,
-    # or a simple list has been passed, which requires
-    # checking for :type argument or defaulting to HASH.
-
 	my $type = 
 	do
 	{
-		if( my $a = reftype $_[0] )
+		if( my $a = ref $_[0] )
 		{
 			if( @_ == 1 )
 			{
@@ -183,9 +157,17 @@ sub
 				{
 					$1
 				}
-                else
+				elsif( defined eval{ %{$_[0]} } )
 				{
-					die "\nUnusable referent: '$a' not hash or array.\n";
+					'HASH'
+				}
+				elsif( defined eval{ @{$_[0]} } )
+				{
+					'ARRAY'
+				}
+				else
+				{
+					die "\nUnusable referent: not hash or array.\n";
 				}
 			}
 			else
@@ -206,7 +188,7 @@ sub
 		}
 		else
 		{
-			die<<'END'
+			croak<<'END'
 Unable to determine base data type:
 The data arguments are not a referent and this 
 class is not derived from another type.
@@ -243,33 +225,24 @@ END
 # the stack has real data on it...
 #
 # all this does is expand a referent into a flat list.
-#
-# caller gets back whatever the argument list expands to.
 
 my $expandvaluz =
 sub
 {
+	my @a = ();
+
 	if( @_ == 1 )
 	{
-        my $type = reftype $_[0];
-
-        if( 'HASH' eq $type )
-        {
-            %{ $_[0] }
-        }
-        elsif( 'ARRAY' eq $type )
-        {
-            @{ $_[0] }
-        }
-        else
-        {
-            die "Bogus data type: '$type' neither hash nor array";
-        }
+		eval { @a = @{ $_[0] } }
+		or
+		eval { @a = %{ $_[0] } }
 	}
 	else
 	{
-		@_
-	}
+		@a = @_
+	};
+
+	@a
 };
 
 ########################################################################
@@ -380,8 +353,6 @@ sub import
 
 	my $argz = &$switches;
 
-	$DB::single = 1 if $debug;
-
 	# if things are getting exported to the caller class
 	# (vs. simply a use base) then build the typeglobs
 	# via symbol and populate them with ref's (data +
@@ -389,10 +360,13 @@ sub import
 
 	if( $argz->{export} )
 	{
+		$DB::single = 1 if $debug;
+
 		unshift @_, $caller;
 
-		# basetype is ARRAY or HASH.  objtype is hash, queue,
-		# or stack.  default array type is stack.
+		# basetype is ARRAY or HASH.
+		# objtype is hash, queue, or stack.
+		# default array type is stack.
 
 		my $basetype = &$objtype;
 
@@ -427,7 +401,7 @@ sub import
 		# where array types really matter.
 
 		*$const = $constructorz{ $argz->{type} }
-			unless defined *{$const}{CODE};
+			unless defined *$const{CODE};
 
 		if( $argz->{type} eq 'hash' )
 		{
@@ -723,9 +697,7 @@ being unknown).
 =over 4
 
 =item :type=hash
-
 =item :type=queue
-
 =item :type=stack
 
 Given a hash or array referent as input these default to 
@@ -744,7 +716,6 @@ data at each stage.
 
 
 =item :verbose
-
 =item :verbose=1
 
 Defaults to one if provided, use ":verbose=0" to turn it
@@ -767,9 +738,7 @@ development.
 =over 4
 
 =item :debug
-
 =item :debug=1
-
 =item :debug=2
 
 Defaults to zero normally, to one if provided. This is
@@ -784,7 +753,6 @@ or
 This is also mainly for use in #! code (see :verbose, above).
 
 =item :export
-
 =item :export=1
 
 Controls whether the symbols are exported after the 
