@@ -28,6 +28,8 @@ use Data::Dumper;
 	$Data::Dumper::Deepcopy         = 0;
 	$Data::Dumper::Quotekeys        = 0;
 
+use FindBin::libs;
+
 use NEXT::init qw( :verbose=1 :debug=0 );
 
 my %baseline_hash = 
@@ -133,6 +135,8 @@ ok @$obj7  == 4,        '@$obj7 == 4';
 ok ref $obj7->[0] eq 'HASH',  '$obj7->[0] is a hash';
 ok $obj7->[-1] eq 'c', '$obj7->[-1] eq c'; 
 
+$DB::single = 1;
+
 my $obj8 = Queue->construct( qw( queue ) );
 
 my $obj9 = Stack->construct( qw( stack ) );
